Struct activitystreams_types::activity::AMove[][src]

pub struct AMove {
    pub kind: MoveType,
    pub move_props: MoveProperties,
    pub object_props: ObjectProperties,
    pub activity_props: ActivityProperties,
}

Indicates that the actor has moved object from origin to target.

If the origin or target are not specified, either can be determined by context.

Fields

Adds all valid move properties to this struct

Adds all valid object properties to this struct

Adds all valid activity properties to this struct