[][src]Struct activitystreams_types::activity::Accept

pub struct Accept {
    pub kind: AcceptType,
    pub accept_props: AcceptProperties,
    pub object_props: ObjectProperties,
    pub activity_props: ActivityProperties,
}

Indicates that the actor accepts the object.

The target property can be used in certain circumstances to indicate the context into which the object has been accepted.

Fields

kind: AcceptTypeaccept_props: AcceptProperties

Adds all valid accept properties to this struct

object_props: ObjectProperties

Adds all valid object properties to this struct

activity_props: ActivityProperties

Adds all valid activity properties to this struct