Struct activitystreams_types::activity::Block [−][src]
pub struct Block {
pub kind: BlockType,
pub block_props: BlockProperties,
pub object_props: ObjectProperties,
pub activity_props: ActivityProperties,
}Indicates that the actor is blocking the object.
Blocking is a stronger form of Ignore. The typical use is to support social systems that allow one user to block activities or content of other users. The target and origin typically have no defined meaning.
Fields
kind: BlockType
block_props: BlockProperties
Adds all valid block properties to this struct
object_props: ObjectProperties
Adds all valid object properties to this struct
activity_props: ActivityProperties
Adds all valid activity properties to this struct