Struct activitystreams_types::activity::Invite[][src]

pub struct Invite {
    pub kind: InviteType,
    pub invite_props: InviteProperties,
    pub object_props: ObjectProperties,
    pub activity_props: ActivityProperties,
}

A specialization of Offer in which the actor is extending an invitation for the object to the target.

Fields

Adds all valid invite properties to this struct

Adds all valid object properties to this struct

Adds all valid activity properties to this struct