[−][src]Struct activitystreams_types::activity::Like
Indicates that the actor likes, recommends or endorses the object.
The target and origin typically have no defined meaning.
Fields
kind: LikeTypelike_props: LikePropertiesAdds all valid like properties to this struct
object_props: ObjectPropertiesAdds all valid object properties to this struct
activity_props: ActivityPropertiesAdds all valid activity properties to this struct