[][src]Struct activitystreams_types::activity::Question

pub struct Question {
    pub kind: QuestionType,
    pub question_props: QuestionProperties,
    pub object_props: ObjectProperties,
    pub activity_props: ActivityProperties,
}

Represents a question being asked.

Question objects are an extension of IntransitiveActivity. That is, the Question object is an Activity, but the direct object is the question itself and therefore it would not contain an object property.

Either of the anyOf and oneOf properties MAY be used to express possible answers, but a Question object MUST NOT have both properties.

Fields

kind: QuestionTypequestion_props: QuestionProperties

Adds all valid question properties to this struct

object_props: ObjectProperties

Adds all valid object properties to this struct

activity_props: ActivityProperties

Adds all valid activity properties to this struct