Struct activitystreams_types::activity::Travel [−][src]
pub struct Travel {
pub kind: TravelType,
pub travel_props: TravelProperties,
pub object_props: ObjectProperties,
pub activity_props: ActivityProperties,
}Indicates that the actor is traveling to target from origin.
Travel is an IntransitiveObject whose actor specifies the direct object. If the target or origin are not specified, either can be determined by context.
Fields
kind: TravelType
travel_props: TravelProperties
Adds all valid travel properties to this struct
object_props: ObjectProperties
Adds all valid object properties to this struct
activity_props: ActivityProperties
Adds all valid activity properties to this struct