Struct activitystreams_types::activity::Update[][src]

pub struct Update {
    pub kind: UpdateType,
    pub update_props: UpdateProperties,
    pub object_props: ObjectProperties,
    pub activity_props: ActivityProperties,
}

Indicates that the actor has updated the object.

Note, however, that this vocabulary does not define a mechanism for describing the actual set of modifications made to object.

The target and origin typically have no defined meaning.

Fields

Adds all valid update properties to this struct

Adds all valid object properties to this struct

Adds all valid activity properties to this struct