[][src]Struct activitystreams_types::collection::properties::CollectionProperties

pub struct CollectionProperties {
    pub items: Value,
    pub total_items: Option<Value>,
    pub current: Option<Value>,
    pub first: Option<Value>,
    pub last: Option<Value>,
}

Collection objects are a specialization of the base Object that serve as a container for other Objects or Links.

The items within a Collection can be ordered or unordered. The OrderedCollection type MAY be used to identify a Collection whose items are always ordered. In the JSON serialization, the unordered items of a Collection are represented using the items property while ordered items are represented using the ordered_items property.

Fields

items: Value

Identifies the items contained in a collection. The items might be ordered or unordered.

  • Range: Object | Link | Ordered List of [ Object | Link ]
  • Functional: false
total_items: Option<Value>

A non-negative integer specifying the total number of objects contained by the logical view of the collection.

This number might not reflect the actual number of items serialized within the Collection object instance.

  • Range: xsd:nonNegativeInteger
  • Functional: true
current: Option<Value>

In a paged Collection, indicates the page that contains the most recently updated member items.

  • Range: CollectionPage | Link
  • Functional: true
first: Option<Value>

In a paged Collection, indicates the furthest preceeding page of items in the collection.

  • Range: CollectionPage | Link
  • Functional: true
last: Option<Value>

In a paged Collection, indicates the furthest proceeding page of the collection.

  • Range: CollectionPage | Link
  • Functional: true

Methods

impl CollectionProperties
[src]

pub fn items_object<T: Object>(&self) -> Result<T>
[src]

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::Deserialize

pub fn set_items_object<T: Object>(&mut self, item: T) -> Result<()>
[src]

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

pub fn items_object_vec<T: Object>(&self) -> Result<Vec<T>>
[src]

Retrieve many values of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::Deserialize

pub fn set_items_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>
[src]

Set many values of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::Deserialize

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

Retrieve many values of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::Deserialize

Set many values of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

pub fn total_items_u64(&self) -> Result<u64>
[src]

Retrieve a value from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

pub fn set_total_items_u64(&mut self, item: u64) -> Result<()>
[src]

Set a value in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

pub fn current_collectionpage<T: CollectionPage>(&self) -> Result<T>
[src]

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

pub fn set_current_collectionpage<T: CollectionPage>(
    &mut self,
    item: T
) -> Result<()>
[src]

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

pub fn first_collectionpage<T: CollectionPage>(&self) -> Result<T>
[src]

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

pub fn set_first_collectionpage<T: CollectionPage>(
    &mut self,
    item: T
) -> Result<()>
[src]

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

pub fn last_collectionpage<T: CollectionPage>(&self) -> Result<T>
[src]

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

pub fn set_last_collectionpage<T: CollectionPage>(
    &mut self,
    item: T
) -> Result<()>
[src]

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize