[][src]Struct activitystreams_types::collection::properties::OrderedCollectionPageProperties

pub struct OrderedCollectionPageProperties {
    pub start_index: Option<Value>,
}

The OrderedCollectionPage type MAY be used to identify a page whose items are strictly ordered.

Fields

start_index: Option<Value>

A non-negative integer value identifying the relative position within the logical view of a strictly ordered collection.

  • Range: xsd:nonNegativeInteger
  • Functional: true

Methods

impl OrderedCollectionPageProperties
[src]

pub fn start_index_u64(&self) -> Result<u64>
[src]

Retrieve a value from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

pub fn set_start_index_u64(&mut self, item: u64) -> Result<()>
[src]

Set a value in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize