Module activitystreams_types::object [−][src]
Namespace for Object types
Modules
| kind |
Namespace for Unit Structs that serialize to strings |
| properties |
Namespace for properties of standard object types |
Structs
| Article |
Represents any kind of multi-paragraph written work. |
| Audio |
Represents an audio document of any kind. |
| Document |
Represents a document of any kind. |
| Event |
Represents any kind of event. |
| Image |
An image document of any kind |
| Note |
Represents a short written work typically less than a single paragraph in length. |
| Page |
Represents a Web Page. |
| Place |
Represents a logical or physical location. |
| Profile |
A Profile is a content object that describes another |
| Relationship |
Describes a relationship between two individuals. |
| Tombstone |
A Tombstone represents a content object that has been deleted. |
| Video |
Represents a video document of any kind. |
Traits
| ObjectExt |
The Object Extension Trait |