[][src]Struct activitystreams_types::object::properties::TombstoneProperties

pub struct TombstoneProperties {
    pub former_type: Option<Value>,
    pub deleted: Option<Value>,
}

Define all the properties of the Tombstone type as described by the Activity Streams vocabulary.

Fields

former_type: Option<Value>

On a Tombstone object, the formerType property identifies the type of the object that was deleted.

  • Range: Object
  • Functional: false
deleted: Option<Value>

On a Tombstone object, the deleted property is a timestamp for when the object was deleted.

  • Range: xsd:dateTime
  • Functional: true

Methods

impl TombstoneProperties
[src]

pub fn former_type_object<T: Object>(&self) -> Result<T>
[src]

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

pub fn set_former_type_object<T: Object>(&mut self, item: T) -> Result<()>
[src]

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

pub fn former_type_object_vec<T: Object>(&self) -> Result<Vec<T>>
[src]

Retrieve many values of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

pub fn set_former_type_object_vec<T: Object>(
    &mut self,
    item: Vec<T>
) -> Result<()>
[src]

Set many values of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

pub fn deleted_string(&self) -> Result<String>
[src]

Retrieve a value from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

pub fn set_deleted_string(&mut self, item: String) -> Result<()>
[src]

Set a value in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

pub fn deleted_utctime(&self) -> Result<UtcTime>
[src]

Retrieve a value from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

pub fn set_deleted_utctime(&mut self, item: UtcTime) -> Result<()>
[src]

Set a value in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize