[][src]Struct activitystreams_types::object::Place

pub struct Place {
    pub object_props: ObjectProperties,
    pub place: PlaceProperties,
    // some fields omitted
}

Represents a logical or physical location.

The Place object is used to represent both physical and logical locations. While numerous existing vocabularies exist for describing locations in a variety of ways, inconsistencies and incompatibilities between those vocabularies make it difficult to achieve appropriate interoperability between implementations. The Place object is included within the Activity vocabulary to provide a minimal, interoperable starting point for describing locations consistently across Activity Streams 2.0 implementations.

The Place object is intentionally flexible. It can, for instance, be used to identify a location simply by name, or by longitude and latitude.

The Place object can also describe an area around a given point using the radius property, the altitude of the location, and a degree of accuracy.

While publishers are not required to use these specific properties and MAY make use of other mechanisms for describing locations, consuming implementations that support the Place object MUST support the use of these properties.

Fields

object_props: ObjectProperties

Adds all valid object properties to this struct

place: PlaceProperties

Adds all valid place properties to this struct