Describes a relationship between two individuals.
The subject and object properties are used to identify the connected individuals.
The Relationship object is used to represent relationships between individuals. It can be
used, for instance, to describe that one person is a friend of another, or that one person is a
member of a particular organization. The intent of modeling Relationship in this way is to allow
descriptions of activities that operate on the relationships in general, and to allow
representation of Collections of relationships.
For instance, many social systems have a notion of a "friends list". These are the collection of
individuals that are directly connected within a person's social graph. Suppose we have a user,
Sally, with direct relationships to users Joe and Jane. Sally follows Joe's updates while Sally
and Jane have a mutual relationship.
Adds all valid object properties to this struct
Adds all valid relationship properties to this struct
Returns the "default value" for a type. Read more
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Serialize this value into the given Serde serializer. Read more
Deserialize this value from the given Serde deserializer. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static