Struct activitystreams_types::activity::properties::ActorAndObjectOptOthers [−][src]
pub struct ActorAndObjectOptOthers {
pub actor: Value,
pub object: Value,
pub origin: Option<Value>,
pub target: Option<Value>,
}Struct with actor, object, and optional origin and target properties
Fields
actor: Value
Describes one or more entities that either performed or are expected to perform the activity.
Any single activity can have multiple actors. The actor MAY be specified using an indirect Link.
- Range:
Object|Link - Functional: false
object: Value
When used within an Activity, describes the direct object of the activity.
For instance, in the activity "John added a movie to his wishlist", the object of the activity is the movie added.
- Range:
Object|Link - Functional: false
origin: Option<Value>
Describes an indirect object of the activity from which the activity is directed.
The precise meaning of the origin is the object of the English preposition "from". For instance, in the activity "John moved an item to List B from List A", the origin of the activity is "List A".
- Range:
Object|Link - Functional: false
target: Option<Value>
Describes the indirect object, or target, of the activity.
The precise meaning of the target is largely dependent on the type of action being described but will often be the object of the English preposition "to". For instance, in the activity "John added a movie to his wishlist", the target of the activity is John's wishlist. An activity can have more than one target
- Range:
Object|Link - Functional: false
Methods
impl ActorAndObjectOptOthers[src]
impl ActorAndObjectOptOtherspub fn actor_object<T: Object>(&self) -> Result<T>[src]
pub fn actor_object<T: Object>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_actor_object<T: Object>(&mut self, item: T) -> Result<()>[src]
pub fn set_actor_object<T: Object>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn actor_object_vec<T: Object>(&self) -> Result<Vec<T>>[src]
pub fn actor_object_vec<T: Object>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_actor_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_actor_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn actor_link<T: Link>(&self) -> Result<T>[src]
pub fn actor_link<T: Link>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_actor_link<T: Link>(&mut self, item: T) -> Result<()>[src]
pub fn set_actor_link<T: Link>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn actor_link_vec<T: Link>(&self) -> Result<Vec<T>>[src]
pub fn actor_link_vec<T: Link>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_actor_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_actor_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn object_object<T: Object>(&self) -> Result<T>[src]
pub fn object_object<T: Object>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_object_object<T: Object>(&mut self, item: T) -> Result<()>[src]
pub fn set_object_object<T: Object>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn object_object_vec<T: Object>(&self) -> Result<Vec<T>>[src]
pub fn object_object_vec<T: Object>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_object_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_object_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn object_link<T: Link>(&self) -> Result<T>[src]
pub fn object_link<T: Link>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_object_link<T: Link>(&mut self, item: T) -> Result<()>[src]
pub fn set_object_link<T: Link>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn object_link_vec<T: Link>(&self) -> Result<Vec<T>>[src]
pub fn object_link_vec<T: Link>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_object_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_object_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn origin_object<T: Object>(&self) -> Result<T>[src]
pub fn origin_object<T: Object>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_origin_object<T: Object>(&mut self, item: T) -> Result<()>[src]
pub fn set_origin_object<T: Object>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn origin_object_vec<T: Object>(&self) -> Result<Vec<T>>[src]
pub fn origin_object_vec<T: Object>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_origin_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_origin_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn origin_link<T: Link>(&self) -> Result<T>[src]
pub fn origin_link<T: Link>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_origin_link<T: Link>(&mut self, item: T) -> Result<()>[src]
pub fn set_origin_link<T: Link>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn origin_link_vec<T: Link>(&self) -> Result<Vec<T>>[src]
pub fn origin_link_vec<T: Link>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_origin_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_origin_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn target_object<T: Object>(&self) -> Result<T>[src]
pub fn target_object<T: Object>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_target_object<T: Object>(&mut self, item: T) -> Result<()>[src]
pub fn set_target_object<T: Object>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn target_object_vec<T: Object>(&self) -> Result<Vec<T>>[src]
pub fn target_object_vec<T: Object>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_target_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_target_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn target_link<T: Link>(&self) -> Result<T>[src]
pub fn target_link<T: Link>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_target_link<T: Link>(&mut self, item: T) -> Result<()>[src]
pub fn set_target_link<T: Link>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn target_link_vec<T: Link>(&self) -> Result<Vec<T>>[src]
pub fn target_link_vec<T: Link>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_target_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_target_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize