[−][src]Struct activitystreams_types::activity::properties::ActorAndOrigin
Struct with actor and origin properties
Fields
actor: ValueDescribes one or more entities that either performed or are expected to perform the activity.
Any single activity can have multiple actors. The actor MAY be specified using an indirect Link.
- Range:
Object|Link - Functional: false
origin: ValueDescribes an indirect object of the activity from which the activity is directed.
The precise meaning of the origin is the object of the English preposition "from". For instance, in the activity "John moved an item to List B from List A", the origin of the activity is "List A".
- Range:
Object|Link - Functional: false
Methods
impl ActorAndOrigin[src]
impl ActorAndOriginpub fn actor_object<T: Object>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_actor_object<T: Object>(&mut self, item: T) -> Result<()> | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn actor_object_vec<T: Object>(&self) -> Result<Vec<T>> | [src] |
Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_actor_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()> | [src] |
Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn actor_link<T: Link>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_actor_link<T: Link>(&mut self, item: T) -> Result<()> | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn actor_link_vec<T: Link>(&self) -> Result<Vec<T>> | [src] |
Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_actor_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()> | [src] |
Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn origin_object<T: Object>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_origin_object<T: Object>(&mut self, item: T) -> Result<()> | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn origin_object_vec<T: Object>(&self) -> Result<Vec<T>> | [src] |
Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_origin_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()> | [src] |
Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn origin_link<T: Link>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_origin_link<T: Link>(&mut self, item: T) -> Result<()> | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn origin_link_vec<T: Link>(&self) -> Result<Vec<T>> | [src] |
Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_origin_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()> | [src] |
Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize