[−][src]Struct activitystreams_types::activity::Add
Indicates that the actor has added the object to the target.
If the target property is not explicitly specified, the target would need to be determined implicitly by context. The origin can be used to identify the context from which the object originated.
Fields
kind: AddTypeadd_props: AddPropertiesAdds all valid add properties to this struct
object_props: ObjectPropertiesAdds all valid object properties to this struct
activity_props: ActivityPropertiesAdds all valid activity properties to this struct