Struct activitystreams_types::activity::Add [−][src]
pub struct Add {
pub kind: AddType,
pub add_props: AddProperties,
pub object_props: ObjectProperties,
pub activity_props: ActivityProperties,
}Indicates that the actor has added the object to the target.
If the target property is not explicitly specified, the target would need to be determined implicitly by context. The origin can be used to identify the context from which the object originated.
Fields
kind: AddType
add_props: AddProperties
Adds all valid add properties to this struct
object_props: ObjectProperties
Adds all valid object properties to this struct
activity_props: ActivityProperties
Adds all valid activity properties to this struct