[−][src]Struct activitystreams_types::activity::Arrive
An IntransitiveActivity that indicates that the actor has arrived at the location.
The origin can be used to identify the context from which the actor originated. The target typically has no defined meaning.
Fields
kind: ArriveTypearrive_props: ArrivePropertiesAdds all valid arrive properties to this struct
object_props: ObjectPropertiesAdds all valid object properties to this struct
activity_props: ActivityPropertiesAdds all valid activity properties to this struct