Struct activitystreams_types::activity::Arrive [−][src]
pub struct Arrive {
pub kind: ArriveType,
pub arrive_props: ArriveProperties,
pub object_props: ObjectProperties,
pub activity_props: ActivityProperties,
}An IntransitiveActivity that indicates that the actor has arrived at the location.
The origin can be used to identify the context from which the actor originated. The target typically has no defined meaning.
Fields
kind: ArriveType
arrive_props: ArriveProperties
Adds all valid arrive properties to this struct
object_props: ObjectProperties
Adds all valid object properties to this struct
activity_props: ActivityProperties
Adds all valid activity properties to this struct