Struct activitystreams_types::activity::Flag[][src]

pub struct Flag {
    pub kind: FlagType,
    pub flag_props: FlagProperties,
    pub object_props: ObjectProperties,
    pub activity_props: ActivityProperties,
}

Indicates that the actor is "flagging" the object.

Flagging is defined in the sense common to many social platforms as reporting content as being inappropriate for any number of reasons.

Fields

Adds all valid flag properties to this struct

Adds all valid object properties to this struct

Adds all valid activity properties to this struct