[−][src]Struct activitystreams_types::activity::Follow
Indicates that the actor is "following" the object.
Following is defined in the sense typically used within Social systems in which the actor is interested in any activity performed by or on the object. The target and origin typically have no defined meaning.
Fields
kind: FollowTypefollow_props: FollowPropertiesAdds all valid follow properties to this struct
object_props: ObjectPropertiesAdds all valid object properties to this struct
activity_props: ActivityPropertiesAdds all valid activity properties to this struct