Struct activitystreams_types::activity::Follow [−][src]
pub struct Follow {
pub kind: FollowType,
pub follow_props: FollowProperties,
pub object_props: ObjectProperties,
pub activity_props: ActivityProperties,
}Indicates that the actor is "following" the object.
Following is defined in the sense typically used within Social systems in which the actor is interested in any activity performed by or on the object. The target and origin typically have no defined meaning.
Fields
kind: FollowType
follow_props: FollowProperties
Adds all valid follow properties to this struct
object_props: ObjectProperties
Adds all valid object properties to this struct
activity_props: ActivityProperties
Adds all valid activity properties to this struct