Struct activitystreams_types::activity::Like[][src]

pub struct Like {
    pub kind: LikeType,
    pub like_props: LikeProperties,
    pub object_props: ObjectProperties,
    pub activity_props: ActivityProperties,
}

Indicates that the actor likes, recommends or endorses the object.

The target and origin typically have no defined meaning.

Fields

Adds all valid like properties to this struct

Adds all valid object properties to this struct

Adds all valid activity properties to this struct