Struct activitystreams_types::activity::Like [−][src]
pub struct Like {
pub kind: LikeType,
pub like_props: LikeProperties,
pub object_props: ObjectProperties,
pub activity_props: ActivityProperties,
}Indicates that the actor likes, recommends or endorses the object.
The target and origin typically have no defined meaning.
Fields
kind: LikeType
like_props: LikeProperties
Adds all valid like properties to this struct
object_props: ObjectProperties
Adds all valid object properties to this struct
activity_props: ActivityProperties
Adds all valid activity properties to this struct