[−][src]Struct activitystreams_types::activity::Question
Represents a question being asked.
Question objects are an extension of IntransitiveActivity. That is, the Question object is an Activity, but the direct object is the question itself and therefore it would not contain an object property.
Either of the anyOf and oneOf properties MAY be used to express possible answers, but a Question object MUST NOT have both properties.
Fields
kind: QuestionTypequestion_props: QuestionPropertiesAdds all valid question properties to this struct
object_props: ObjectPropertiesAdds all valid object properties to this struct
activity_props: ActivityPropertiesAdds all valid activity properties to this struct