Struct activitystreams_types::activity::Undo [−][src]
pub struct Undo {
pub kind: UndoType,
pub undo_props: UndoProperties,
pub object_props: ObjectProperties,
pub activity_props: ActivityProperties,
}Indicates that the actor is undoing the object.
In most cases, the object will be an Activity describing some previously performed action (for instance, a person may have previously "liked" an article but, for whatever reason, might choose to undo that like at some later point in time).
The target and origin typically have no defined meaning.
Fields
kind: UndoType
undo_props: UndoProperties
Adds all valid undo properties to this struct
object_props: ObjectProperties
Adds all valid object properties to this struct
activity_props: ActivityProperties
Adds all valid activity properties to this struct