[−][src]Struct activitystreams_types::collection::properties::CollectionPageProperties
The CollectionPage type extends from the base Collection type and inherits all of it's
properties.
Fields
part_of: Option<Value>Identifies the Collection to which a CollectionPage objects items belong.
Range: Collection | Link
Functional: true
next: Option<Value>In a paged Collection, indicates the next page of items.
- Range:
CollectionPage|Link - Functional: true
prev: Option<Value>In a paged Collection, identifies the previous page of items.
- Range:
CollectionPage|Link - Functional: true
Methods
impl CollectionPageProperties[src]
impl CollectionPagePropertiespub fn part_of_link<T: Link>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_part_of_link<T: Link>(&mut self, item: T) -> Result<()> | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn part_of_collection<T: Collection>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_part_of_collection<T: Collection>(&mut self, item: T) -> Result<()> | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn next_link<T: Link>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_next_link<T: Link>(&mut self, item: T) -> Result<()> | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn next_collectionpage<T: CollectionPage>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_next_collectionpage<T: CollectionPage>( | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn prev_link<T: Link>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_prev_link<T: Link>(&mut self, item: T) -> Result<()> | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn prev_collectionpage<T: CollectionPage>(&self) -> Result<T> | [src] |
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
pub fn set_prev_collectionpage<T: CollectionPage>( | [src] |
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize