Struct activitystreams_types::collection::UnorderedCollectionPage [−][src]
pub struct UnorderedCollectionPage {
pub object_props: ObjectProperties,
pub collection_props: CollectionProperties,
pub collection_page_props: CollectionPageProperties,
// some fields omitted
}Used to represent distinct subsets of items from a Collection.
Fields
object_props: ObjectProperties
Adds all valid object properties to this struct
collection_props: CollectionProperties
Adds all valid collection properties to this struct
collection_page_props: CollectionPageProperties
Adds all valid collection page properties to this struct