Struct activitystreams_types::object::properties::ProfileProperties [−][src]
pub struct ProfileProperties {
pub describes: Value,
}Define all the properties of the Profile type as described by the Activity Streams vocabulary.
Fields
describes: Value
On a Profile object, the describes property identifies the object described by the
Profile.
- Range:
Object - Functional: true
Methods
impl ProfileProperties[src]
impl ProfilePropertiespub fn describes_object<T: Object>(&self) -> Result<T>[src]
pub fn describes_object<T: Object>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_describes_object<T: Object>(&mut self, item: T) -> Result<()>[src]
pub fn set_describes_object<T: Object>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize