Struct activitystreams_types::object::properties::RelationshipProperties [−][src]
pub struct RelationshipProperties { /* fields omitted */ }Define all the properties of the Relationship type as described by the Activity Streams vocabulary.
Methods
impl RelationshipProperties[src]
impl RelationshipPropertiespub fn subject_object<T: Object>(&self) -> Result<T>[src]
pub fn subject_object<T: Object>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_subject_object<T: Object>(&mut self, item: T) -> Result<()>[src]
pub fn set_subject_object<T: Object>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn subject_link<T: Link>(&self) -> Result<T>[src]
pub fn subject_link<T: Link>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_subject_link<T: Link>(&mut self, item: T) -> Result<()>[src]
pub fn set_subject_link<T: Link>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn object_object<T: Object>(&self) -> Result<T>[src]
pub fn object_object<T: Object>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_object_object<T: Object>(&mut self, item: T) -> Result<()>[src]
pub fn set_object_object<T: Object>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn object_object_vec<T: Object>(&self) -> Result<Vec<T>>[src]
pub fn object_object_vec<T: Object>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_object_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_object_object_vec<T: Object>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn object_link<T: Link>(&self) -> Result<T>[src]
pub fn object_link<T: Link>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_object_link<T: Link>(&mut self, item: T) -> Result<()>[src]
pub fn set_object_link<T: Link>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn object_link_vec<T: Link>(&self) -> Result<Vec<T>>[src]
pub fn object_link_vec<T: Link>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_object_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>[src]
pub fn set_object_link_vec<T: Link>(&mut self, item: Vec<T>) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn relationship_object<T: Object>(&self) -> Result<T>[src]
pub fn relationship_object<T: Object>(&self) -> Result<T>Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_relationship_object<T: Object>(&mut self, item: T) -> Result<()>[src]
pub fn set_relationship_object<T: Object>(&mut self, item: T) -> Result<()>Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize
pub fn relationship_object_vec<T: Object>(&self) -> Result<Vec<T>>[src]
pub fn relationship_object_vec<T: Object>(&self) -> Result<Vec<T>>Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using this a lot.
Possible errors from this method are Error::Deserialize
pub fn set_relationship_object_vec<T: Object>(
&mut self,
item: Vec<T>
) -> Result<()>[src]
pub fn set_relationship_object_vec<T: Object>(
&mut self,
item: Vec<T>
) -> Result<()>Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using this a lot.
Possible errors from this method are Error::Serialize