Define all the properties of the Tombstone type as described by the Activity Streams vocabulary.
On a Tombstone object, the formerType property identifies the type of the object that was
deleted.
- Range:
Object
- Functional: false
On a Tombstone object, the deleted property is a timestamp for when the object was
deleted.
- Range:
xsd:dateTime
- Functional: true
Retrieve a value of type T from the given struct
This method deserializes the item from JSON, so be wary of using
this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
Set a value of type T in the given struct
This method serializes the item to JSON, so be wary of using this a
lot.
Possible errors from this method are Error::Serialize
Retrieve many values of type T from the given struct
This method deserializes the item from JSON, so be wary of using
this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
Set many values of type T in the given struct
This method serializes the item to JSON, so be wary of using
this a lot.
Possible errors from this method are Error::Serialize
Retrieve a value from the given struct
This method deserializes the item from JSON, so be wary of using
this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
Set a value in the given struct
This method serializes the item to JSON, so be wary of using this a
lot.
Possible errors from this method are Error::Serialize
Retrieve a value from the given struct
This method deserializes the item from JSON, so be wary of using
this a lot.
Possible errors from this method are Error::NotFound and
Error::Deserialize
Set a value in the given struct
This method serializes the item to JSON, so be wary of using this a
lot.
Possible errors from this method are Error::Serialize
Returns the "default value" for a type. Read more
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Serialize this value into the given Serde serializer. Read more
Deserialize this value from the given Serde deserializer. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static