Struct activitystreams_types::object::properties::TombstoneProperties[][src]

pub struct TombstoneProperties {
    pub former_type: Option<Value>,
    pub deleted: Option<Value>,
}

Define all the properties of the Tombstone type as described by the Activity Streams vocabulary.

Fields

On a Tombstone object, the formerType property identifies the type of the object that was deleted.

  • Range: Object
  • Functional: false

On a Tombstone object, the deleted property is a timestamp for when the object was deleted.

  • Range: xsd:dateTime
  • Functional: true

Methods

impl TombstoneProperties
[src]

Retrieve a value of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

Set a value of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

Retrieve many values of type T from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

Set many values of type T in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

Retrieve a value from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

Set a value in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize

Retrieve a value from the given struct

This method deserializes the item from JSON, so be wary of using this a lot.

Possible errors from this method are Error::NotFound and Error::Deserialize

Set a value in the given struct

This method serializes the item to JSON, so be wary of using this a lot.

Possible errors from this method are Error::Serialize