Represents a logical or physical location.
The Place object is used to represent both physical and logical locations. While numerous
existing vocabularies exist for describing locations in a variety of ways, inconsistencies and
incompatibilities between those vocabularies make it difficult to achieve appropriate
interoperability between implementations. The Place object is included within the Activity
vocabulary to provide a minimal, interoperable starting point for describing locations
consistently across Activity Streams 2.0 implementations.
The Place object is intentionally flexible. It can, for instance, be used to identify a location
simply by name, or by longitude and latitude.
The Place object can also describe an area around a given point using the radius property, the
altitude of the location, and a degree of accuracy.
While publishers are not required to use these specific properties and MAY make use of other
mechanisms for describing locations, consuming implementations that support the Place object
MUST support the use of these properties.
Adds all valid object properties to this struct
Adds all valid place properties to this struct
Returns the "default value" for a type. Read more
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Serialize this value into the given Serde serializer. Read more
Deserialize this value from the given Serde deserializer. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static