Struct activitystreams_types::object::Profile[][src]

pub struct Profile {
    pub object_props: ObjectProperties,
    pub profile: ProfileProperties,
    // some fields omitted
}

A Profile is a content object that describes another Object, typically used to describe Actor Type objects.

The describes property is used to reference the object being described by the profile.

Fields

Adds all valid object properties to this struct

Adds all valid profile properties to this struct