Struct activitystreams_types::object::Relationship[][src]

pub struct Relationship {
    pub object_props: ObjectProperties,
    pub relationship: RelationshipProperties,
    // some fields omitted
}

Describes a relationship between two individuals.

The subject and object properties are used to identify the connected individuals.

The Relationship object is used to represent relationships between individuals. It can be used, for instance, to describe that one person is a friend of another, or that one person is a member of a particular organization. The intent of modeling Relationship in this way is to allow descriptions of activities that operate on the relationships in general, and to allow representation of Collections of relationships.

For instance, many social systems have a notion of a "friends list". These are the collection of individuals that are directly connected within a person's social graph. Suppose we have a user, Sally, with direct relationships to users Joe and Jane. Sally follows Joe's updates while Sally and Jane have a mutual relationship.

Fields

Adds all valid object properties to this struct

Adds all valid relationship properties to this struct