[−][src]Struct activitystreams_types::object::Tombstone
A Tombstone represents a content object that has been deleted.
It can be used in Collections to signify that there used to be an object at this position, but it has been deleted.
Fields
object_props: ObjectPropertiesAdds all valid object properties to this struct
tombstone_props: TombstonePropertiesAdds all valid tombstone properties to this struct