Struct activitystreams_types::object::Tombstone[][src]

pub struct Tombstone {
    pub object_props: ObjectProperties,
    pub tombstone_props: TombstoneProperties,
    // some fields omitted
}

A Tombstone represents a content object that has been deleted.

It can be used in Collections to signify that there used to be an object at this position, but it has been deleted.

Fields

Adds all valid object properties to this struct

Adds all valid tombstone properties to this struct